@@ -1,4 +1,4 @@
-# $Id: HiClimR.R, v 1.1.1 2014/07/14 12:07:00 EPS JHU $                #
+# $Id: HiClimR.R, v 1.1.2 2014/07/26 12:07:00 EPS JHU $                #
 #----------------------------------------------------------------------#
 # This is the main function of                                         #
 # HiClimR (Hierarchical Climate Regionalization) R package             #
@@ -78,7 +78,7 @@
 #----------------------------------------------------------------------#
 #  Version  |  Date      |  Comment   |  Author       |  Email         #
 #----------------------------------------------------------------------#
-#           |  May 1992  |  Oringinal |  F. Murtagh   |                #
+#           |  May 1992  |  Original  |  F. Murtagh   |                #
 #           |  Dec 1996  |  Modified  |  Ross Ihaka   |                #
 #           |  Apr 1998  |  Modified  |  F. Leisch    |                #
 #           |  Jun 2000  |  Modified  |  F. Leisch    |                #
@@ -96,6 +96,7 @@
 #  1.0.9    |  05/07/14  |  CRAN      |  Hamada Badr  |  badr@jhu.edu  #
 #  1.1.0    |  05/15/14  |  Updated   |  Hamada Badr  |  badr@jhu.edu  #
 #  1.1.1    |  07/14/14  |  Updated   |  Hamada Badr  |  badr@jhu.edu  #
+#  1.1.2    |  07/26/14  |  Updated   |  Hamada Badr  |  badr@jhu.edu  #
 #----------------------------------------------------------------------#
 # COPYRIGHT(C) Department of Earth and Planetary Sciences, JHU.        #
 #----------------------------------------------------------------------#
@@ -271,6 +272,12 @@ HiClimR <- function (
     # This is equivalent to upper triangular part of dissimilarity matrix
     r <- r[col(r) < row(r)]
 
+    # Re-adding the mean for nonstandardized data (July 26, 2014)
+    if (!standardize)
+    {
+        x <- x + xmean[-mask]
+    }
+
     # Reconstruct data from PCs if requested
     if (!is.null(nPC))
     {
